==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/sq.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Duke ngarkuar pamjen paraprake...",
    "Saved" : "E ruajtur",
    "Admin" : "Admin",
    "a safe home for all your data" : "një vënd i sigurtë për të dhënat e tua ",
    "The given name is too long" : "Emri i dhënë është tepër i gjatë ",
    "The given web address is too long" : "Adresa e dhënë e ueb-it është tepër e gjate ",
    "The given slogan is too long" : "Slogani i dhënë është shumë i gjatë ",
    "The given color is invalid" : "Ngjyra e dhënë është invalide ",
    "No file uploaded" : "Asnjë skedar i ngarkuar",
    "Unsupported image type" : "Lloj imazhi i pa suportuar",
    "You are already using a custom theme" : "Ju jeni duke përdorur një temë të zakonshme tashmë",
    "Theming" : "Duke vendosur theme-n",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming bën të mundur për të përshtatur lehtësisht pamjen dhe ndjenjën e instancës suaj dhe klientëve të mbështetur. Kjo do të jetë e dukshme për të gjithë përdoruesit.",
    "Name" : "Emri",
    "Reset to default" : "Rivendos tek të paracaktuarat",
    "Web address" : "Adresa e Web",
    "Web address https://…" : "Adresë uebi https://...",
    "Slogan" : "Sllogan",
    "Color" : "Ngjyrë ",
    "Logo" : "Logo",
    "Upload new logo" : "Ngarko logo të re ",
    "Login image" : "Imazhi i hyrjes",
    "Upload new login background" : "Ngarko background të ri hyrjeje",
    "Remove background image" : "Hiqni imazhin në sfond",
    "reset to default" : "rivendos tek të paracaktuarat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/theming/l10n/sq.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Duke ngarkuar pamjen paraprake...",
    "Saved" : "E ruajtur",
    "Admin" : "Admin",
    "a safe home for all your data" : "një vënd i sigurtë për të dhënat e tua ",
    "The given name is too long" : "Emri i dhënë është tepër i gjatë ",
    "The given web address is too long" : "Adresa e dhënë e ueb-it është tepër e gjate ",
    "The given slogan is too long" : "Slogani i dhënë është shumë i gjatë ",
    "The given color is invalid" : "Ngjyra e dhënë është invalide ",
    "No file uploaded" : "Asnjë skedar i ngarkuar",
    "Unsupported image type" : "Lloj imazhi i pa suportuar",
    "Theming" : "Duke vendosur theme-n",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming bën të mundur për të përshtatur lehtësisht pamjen dhe ndjenjën e instancës suaj dhe klientëve të mbështetur. Kjo do të jetë e dukshme për të gjithë përdoruesit.",
    "Name" : "Emri",
    "Reset to default" : "Rivendos tek të paracaktuarat",
    "Slogan" : "Sllogan",
    "Color" : "Ngjyrë ",
    "Logo" : "Logo",
    "Upload new logo" : "Ngarko logo të re ",
    "Login image" : "Imazhi i hyrjes",
    "Upload new login background" : "Ngarko background të ri hyrjeje",
    "Remove background image" : "Hiqni imazhin në sfond",
    "You are already using a custom theme" : "Ju jeni duke përdorur një temë të zakonshme tashmë",
    "reset to default" : "rivendos tek të paracaktuarat",
    "Web address" : "Adresa e Web",
    "Web address https://…" : "Adresë uebi https://..."
},
"nplurals=2; plural=(n != 1);");
